# ZenCart plugin for Quickpay

## Features
- This version supports basic subscription payment and payment links.
- There is no data posted to Quickpay gateway through client browser. Payments are handled by API server to server communication and reuseable payment links . This means, that this module is independent of user browser and user technology limitations.
- Merchant can send a reuseable payment link (from order admin) to a customer if a  transaction has been interrupted for some reason.
- Simplicity. The basic concept of this version is
    - get order status from API
    - create order in gateway if no order and payment exists
    - create or update reusable payment link to payment window (same order number)
    - handle webshop order in callback according to status from gateway API
- Payment status records are not added to order history comments. They are output in order admin seperately from an API status log function instead

### OBS:
*If using payment links from admin, you could take advantage in implementing a PDF invoice contribution . As is now, the callback function (callback10.php) redirects customers to their account order overview page after succesful payment using admin provided payment links.*

## IMPORTANT:
Using this module you acknowledge, that the Author can not be made responsible for any kind of damages,
errors or problems caused by wrong or correct implementation of this module.

## REQUIREMENTS:
You must have the following:
- Zen-Cart 1.5.7 based webshop
    - Last tested with: 1.5.7c
- QuickPay Payment login (get it here: https://manage.quickpay.net).
- The php-extensions Curl and SimpleXml must be installed on your webserver in order to use the module for payments.


## INSTALLATION INSTRUCTIONS:
### Step 0
- Make a BACKUP

### Step 1
- (I) New installation
    - copy files & directories as following (choose Replace All on prompt):
        - (callback10.php + images + includes) to the webshop root directory.
        - all files and directories FROM "qp10admin" directory to the ZenCart admin directory (it is automatically renamed after instalation with random words (for eg. Admin-Is-Hiding))

- (II) Modified installations
    - make sure you apply all modifications - marked with "// Quickpay ..." in your webshop files:
        ```
        (admin)/orders.php
        includes/classes/order.php
        includes/templates/tmplate_default/templates/tpl_ajax_checkout_confirmation_default.php
        includes/templates/tmplate_default/templates/tpl_checkout_confirmation_default.php
        includes/templates/responsive_classic/templates/tpl_ajax_checkout_confirmation_default.php
        includes/templates/responsive_classic/templates/tpl_checkout_confirmation_default.php
        ```
        - OBS:
            - Apply to your theme too, if different from standard
                ```
                includes/modules/pages/checkout_confirmation/jscript_double_submit.php
                ```
            - Apply to your theme needs, if different from standard handles agreement to conditions
    - Then copy all other remaining files to your webshop directory as is in Step 1, **(I) New installation**.
        - You will find the files needed for copying to your admin directory in the folder named "qp10admin".

### STEP 2
- Go into the Shop Administration->Modules->Payment, and install & enable the Online payment module.
    - If you have a previous installation of the QuickPay-module then first remove/uninstall the old version
- Provide:
    - Agreement ID (eg. 123456)
    - Merchant (Shop) ID (eg. 123456). Agreement ID is your Payment window Agreement ID
    - API key for your  API user (API user -> API key)
    - select which Acquirers and cards/payment options you want to accept,
    - set up AutoCapture (yes/no)
    - set up AutoFee (yes/no)
    - set up the subscription type (normal (one time payment)/subscription)
- Obs:
    - You have up to 5 payment options available. But if you need more cards/payment options, then please feel free to change the number in line 42 of includes/modules/payment/quickpay_advanced.php
- Then click "Update" button.

### STEP 3
- Test your new QuickPay Payment enabled website...
    - available test cards, see: [https://learn.quickpay.net/tech-talk/appendixes/test/#test-data](https://learn.quickpay.net/tech-talk/appendixes/test/#test-data)
- You can manage the online payment transaction from within your webshop (Administration)->Orders


## CHANGELOG

1.0.2 Adjust compatibility with ZenCart versions 1.5.x
- removed unnecessary files/directories:
    - qp10admin\classes\order.php
    - includes\classes\_notes\dwsync.xml
    - includes\modules\pages\checkout_confirmation\jscript_main.php
- added required files/directories:
    - includes\templates\responsive_classic\templates\tpl_ajax_checkout_confirmation.php
    - includes\templates\responsive_classic\templates\tpl_checkout_confirmation.php
    - includes\modules\pages\checkout_confirmation\jscript_double_submit.php
- code adjustement/formatting in files
- added/modified code in:
    - qp10admin\orders.php (ZenCart framework file)
    - includes\classes\order.php (ZenCart framework file)
    - includes\templates\template_default\templates\tpl_ajax_checkout_confirmation_default.php (ZenCart framework file)
    - includes\templates\template_default\templates\tpl_checkout_confirmation_default.php (ZenCart framework file)
    - includes\modules\payment\quickpay_advanced.php (QuickPay file)

1.0.1 Initial version
